Source-Changes-HG archive

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index][Old Index]

[src/trunk]: src/sys/arch Make ci_want_resched a u_int.



details:   https://anonhg.NetBSD.org/src/rev/d801aa72e75c
branches:  trunk
changeset: 461378:d801aa72e75c
user:      ad <ad%NetBSD.org@localhost>
date:      Sun Nov 24 15:40:24 2019 +0000

description:
Make ci_want_resched a u_int.

diffstat:

 sys/arch/alpha/include/cpu.h |  5 +++--
 sys/arch/ia64/include/cpu.h  |  5 +++--
 2 files changed, 6 insertions(+), 4 deletions(-)

diffs (38 lines):

diff -r 0462db4008d7 -r d801aa72e75c sys/arch/alpha/include/cpu.h
--- a/sys/arch/alpha/include/cpu.h      Sun Nov 24 15:37:39 2019 +0000
+++ b/sys/arch/alpha/include/cpu.h      Sun Nov 24 15:40:24 2019 +0000
@@ -1,4 +1,4 @@
-/* $NetBSD: cpu.h,v 1.84 2018/08/22 01:05:21 msaitoh Exp $ */
+/* $NetBSD: cpu.h,v 1.85 2019/11/24 15:40:24 ad Exp $ */
 
 /*-
  * Copyright (c) 1998, 1999, 2000, 2001 The NetBSD Foundation, Inc.
@@ -121,7 +121,8 @@
        struct mchkinfo ci_mcinfo;      /* machine check info */
        cpuid_t ci_cpuid;               /* our CPU ID */
        struct cpu_softc *ci_softc;     /* pointer to our device */
-       u_long ci_want_resched;         /* preempt current process */
+       u_int ci_want_resched;          /* preempt current process */
+       u_int ci_unused;                /* unused */
        u_long ci_intrdepth;            /* interrupt trap depth */
        struct trapframe *ci_db_regs;   /* registers for debuggers */
        uint64_t ci_pcc_freq;           /* cpu cycles/second */
diff -r 0462db4008d7 -r d801aa72e75c sys/arch/ia64/include/cpu.h
--- a/sys/arch/ia64/include/cpu.h       Sun Nov 24 15:37:39 2019 +0000
+++ b/sys/arch/ia64/include/cpu.h       Sun Nov 24 15:40:24 2019 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: cpu.h,v 1.18 2019/11/23 19:40:35 ad Exp $      */
+/*     $NetBSD: cpu.h,v 1.19 2019/11/24 15:45:41 ad Exp $      */
 
 /*-
  * Copyright (c) 2006 The NetBSD Foundation, Inc.
@@ -107,7 +107,8 @@
        struct lwp *ci_fpcurlwp;        /* current owner of the FPU */
        paddr_t ci_curpcb;              /* PA of current HW PCB */
        struct pcb *ci_idle_pcb;        /* our idle PCB */
-       u_long ci_want_resched;         /* preempt current process */
+       u_int ci_want_resched;          /* preempt current process */
+       u_int ci_unused;                /* unused */
        u_long ci_intrdepth;            /* interrupt trap depth */
        struct trapframe *ci_db_regs;   /* registers for debuggers */
        uint64_t ci_clock;              /* clock counter */



Home | Main Index | Thread Index | Old Index